Coverage report

File | statements | missing | excluded | coverage
--- | --- | --- | --- | ---
.tox/p311/lib/python3.10/site-packages/scicom/__init__.py | 0 | 0 | 0 | 100%
.tox/p311/lib/python3.10/site-packages/scicom/historicalletters/__init__.py | 0 | 0 | 0 | 100%
.tox/p311/lib/python3.10/site-packages/scicom/historicalletters/agents.py | 113 | 8 | 0 | 93%
.tox/p311/lib/python3.10/site-packages/scicom/historicalletters/interface.py | 39 | 39 | 0 | 0%
.tox/p311/lib/python3.10/site-packages/scicom/historicalletters/model.py | 108 | 6 | 0 | 94%
.tox/p311/lib/python3.10/site-packages/scicom/historicalletters/server.py | 22 | 0 | 0 | 100%
.tox/p311/lib/python3.10/site-packages/scicom/historicalletters/space.py | 27 | 0 | 0 | 100%
.tox/p311/lib/python3.10/site-packages/scicom/historicalletters/utils.py | 39 | 0 | 0 | 100%
.tox/p311/lib/python3.10/site-packages/scicom/interface.py | 15 | 15 | 0 | 0%
.tox/p311/lib/python3.10/site-packages/scicom/knowledgespread/SimpleContinuousModule.py | 23 | 23 | 0 | 0%
.tox/p311/lib/python3.10/site-packages/scicom/knowledgespread/__init__.py | 0 | 0 | 0 | 100%
.tox/p311/lib/python3.10/site-packages/scicom/knowledgespread/agents.py | 71 | 71 | 0 | 0%
.tox/p311/lib/python3.10/site-packages/scicom/knowledgespread/interface.py | 5 | 5 | 0 | 0%
.tox/p311/lib/python3.10/site-packages/scicom/knowledgespread/model.py | 71 | 71 | 0 | 0%
.tox/p311/lib/python3.10/site-packages/scicom/knowledgespread/server.py | 69 | 69 | 0 | 0%
.tox/p311/lib/python3.10/site-packages/scicom/knowledgespread/utils.py | 127 | 127 | 0 | 0%
.tox/p311/lib/python3.10/site-packages/scicom/run.py | 10 | 10 | 0 | 0%
.tox/p311/lib/python3.10/site-packages/scicom/utilities/__init__.py | 0 | 0 | 0 | 100%
.tox/p311/lib/python3.10/site-packages/scicom/utilities/statistics.py | 57 | 0 | 0 | 100%
Total | 796 | 444 | 0 | 44%

No items found using the specified filter.